X-Git-Url: https://git.saurik.com/wxWidgets.git/blobdiff_plain/78d14f80e9a72041ede52c30d912ec5cef21b1b3..6ee3c06421446908fabe9de45b8e0c7519c28c24:/contrib/src/xrc/xh_bmpbt.cpp

diff --git a/contrib/src/xrc/xh_bmpbt.cpp b/contrib/src/xrc/xh_bmpbt.cpp
index 476609dfab..3e94df6875 100644
--- a/contrib/src/xrc/xh_bmpbt.cpp
+++ b/contrib/src/xrc/xh_bmpbt.cpp
@@ -1,6 +1,6 @@
 /////////////////////////////////////////////////////////////////////////////
 // Name:        xh_bmpbt.cpp
 // Purpose:     XML resource for bitmap buttons
 // Author:      Brian Gavin
 // Created:     2000/09/09
 // RCS-ID:      $Id$
@@ -22,28 +22,32 @@
 #include "wx/xrc/xh_bmpbt.h"
 #include <wx/bmpbuttn.h>
 
+IMPLEMENT_DYNAMIC_CLASS(wxBitmapButtonXmlHandler, wxXmlResourceHandler)
+
 wxBitmapButtonXmlHandler::wxBitmapButtonXmlHandler() 
 : wxXmlResourceHandler() 
 {
-    ADD_STYLE(wxBU_AUTODRAW);
-    ADD_STYLE(wxBU_LEFT);
-    ADD_STYLE(wxBU_RIGHT);
-    ADD_STYLE(wxBU_TOP);
-    ADD_STYLE(wxBU_BOTTOM);
+    XRC_ADD_STYLE(wxBU_AUTODRAW);
+    XRC_ADD_STYLE(wxBU_LEFT);
+    XRC_ADD_STYLE(wxBU_RIGHT);
+    XRC_ADD_STYLE(wxBU_TOP);
+    XRC_ADD_STYLE(wxBU_BOTTOM);
     AddWindowStyles();
 }
 
-
 wxObject *wxBitmapButtonXmlHandler::DoCreateResource()
 { 
-    wxBitmapButton *button = new wxBitmapButton(m_parentAsWindow,
-                                    GetID(),
-                                    GetBitmap(wxT("bitmap")),
-                                    GetPosition(), GetSize(),
-                                    GetStyle(wxT("style"), wxBU_AUTODRAW),
-                                    wxDefaultValidator,
-                                    GetName());
-    if (GetBool(wxT("default"), 0) == 1) button->SetDefault();
+    XRC_MAKE_INSTANCE(button, wxBitmapButton)
+
+    button->Create(m_parentAsWindow,
+                   GetID(),
+                   GetBitmap(wxT("bitmap")),
+                   GetPosition(), GetSize(),
+                   GetStyle(wxT("style"), wxBU_AUTODRAW),
+                   wxDefaultValidator,
+                   GetName());
+    if (GetBool(wxT("default"), 0))
+        button->SetDefault();
     SetupWindow(button);
     
     if (!GetParamValue(wxT("selected")).IsEmpty())
@@ -56,11 +60,7 @@ wxObject *wxBitmapButtonXmlHandler::DoCreateResource()
     return button;
 }
 
-
-
 bool wxBitmapButtonXmlHandler::CanHandle(wxXmlNode *node)
 {
     return IsOfClass(node, wxT("wxBitmapButton"));
 }
-
-
@@ -1,6 +1,6 @@
 /////////////////////////////////////////////////////////////////////////////
 // Name:        xh_bmpbt.cpp
-// Purpose:     XML resource for bitmap buttons
+// Purpose:     XRC resource for bitmap buttons
 // Author:      Brian Gavin
 // Created:     2000/09/09